/*
 * Kerneos
 * Copyright (C) 2012 Bull S.A.S.
 * Contact: jasmine AT ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * $Id$
 */

package org.ow2.kerneos.examples.extensions.insurance.auto.command {
import com.adobe.cairngorm.commands.ICommand;
import com.adobe.cairngorm.control.CairngormEvent;

import mx.rpc.IResponder;
import mx.rpc.events.FaultEvent;
import mx.rpc.events.ResultEvent;

import org.ow2.kerneos.examples.extensions.common.event.InsuranceEvent;
import org.ow2.kerneos.examples.extensions.insurance.auto.MyModuleFragment;
import org.ow2.kerneos.examples.extensions.insurance.auto.business.*;
import org.ow2.kerneos.examples.extensions.insurance.auto.event.ModuleFragmentEvent;

/**
 * The command class from the cairngorm model.
 */
public class ModuleFragmentCommand implements ICommand, IResponder {
    /**
     * Retrieve the delegate and use it to make the call.
     */
    public function execute(event:CairngormEvent):void {
        ////////////////////////////////////////////////
        //                                            //
        //             Handle the execution           //
        //                                            //
        ////////////////////////////////////////////////


        // - Get the delegate
        // - Register the responder
        // - Make the call
        // Example :
        var delegate:IModuleFragmentDelegate = MyModuleFragment.getInstance().getModel().getMyDelegate();
        delegate.responder = this;
        delegate.callServerSide((event as ModuleFragmentEvent).insurancePolicyRequest);
    }

    /**
     * Handle the result of the server call.
     */
    public function result(data:Object):void {
        ////////////////////////////////////////////////
        //                                            //
        //             Handle the result              //
        //                                            //
        ////////////////////////////////////////////////
        var insuranceEvent:InsuranceEvent =
                new InsuranceEvent(InsuranceEvent.INSURANCE_APPROVED, (data as ResultEvent).result as Number);
        //Forward result to the parent module
        MyModuleFragment.getInstance().getParentKerneosModule().getDispatcher().dispatchEvent(insuranceEvent);
    }

    /**
     * Raise an alert when something is wrong.
     */
    public function fault(event:Object):void {

        ////////////////////////////////////////
        //                                    //
        //             Handle fault           //
        //                                    //
        ////////////////////////////////////////
        var faultEvent:FaultEvent = FaultEvent(event);
        var insuranceEvent:InsuranceEvent =
                new InsuranceEvent(InsuranceEvent.INSURANCE_REJECTED, NaN, faultEvent.fault.faultString);
        //Forward result to the parent module
        MyModuleFragment.getInstance().getParentKerneosModule().getDispatcher().dispatchEvent(insuranceEvent);
    }

}
}
